@@ -1,3 +1,4 @@
+import os
 from functools import wraps
 from fabric.context_managers import prefix, cd
 from fabric.contrib.files import upload_template
@@ -93,3 +94,6 @@ def delete_pyc():
     """ Deletes *.pyc files from project source dir """
     run("find . -name '*.pyc' -delete")
 
+def _data_path(fname):
+    """Return the path to a data file of ours."""
+    return os.path.join(os.path.split(__file__)[0], fname)
